<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-plan?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// P
	'plan_description' => 'Este plugin mejora la página "Mapa del sitio" del área privada mostrando una estructura desplegable y permitiendo filtrar por estado del artículo.',
	'plan_nom' => 'Mapa del sitio en el área privada',
	'plan_slogan' => 'Mejora la página del mapa del sitio del área privada',
];
